@@ -6,7 +6,7 @@ import uuid
 import pickle
 import sys
 
-from bravado.exception import HTTPBadGateway, HTTPUnauthorized, HTTPBadRequest, HTTPNotFound, HTTPGatewayTimeout
+from bravado.exception import HTTPBadGateway, HTTPUnauthorized, HTTPBadRequest, HTTPNotFound, HTTPGatewayTimeout, HTTPServiceUnavailable
 
 
 class BitmexClient:
@@ -26,7 +26,7 @@ class BitmexClient:
                 0][str(prop)]
             self._last_wallet_balance = wallet_balance
             return wallet_balance
-        except HTTPBadRequest:
+        except (HTTPBadRequest, HTTPGatewayTimeout):
             return self._last_wallet_balance
 
     def get_position(self, symbol, prop):
@@ -71,13 +71,18 @@ class BitmexClient:
                                                 ).result()[0][0]['price']
             self._last_currentprice[symbol] = price
             return price
-        except (IndexError, HTTPBadRequest, HTTPGatewayTimeout, HTTPBadGateway) as e:
+        except (IndexError, HTTPBadRequest, HTTPGatewayTimeout, HTTPBadGateway, HTTPServiceUnavailable) as e:
             if 'expired' in str(e):
-                # now = datetime.datetime.utcnow()
-                # print('Current price expired error. Time:', now, ' Server Time:', now.strftime("%m/%d/%Y, %H:%M:%S"), 'Returning last price.', flush=True)
-                print('Current price expired error. Returning last price.', flush=True)
+                print('Current price expired. Returning last price.', flush=True)
+            elif 'Service Unavailable' in str(e):
+                print('Server maintenance. Trying to reconnect in 5 Minutes...')
+                while True:
+                    time.sleep(360)
+                    current_price = self.get_current_price(symbol)
+                    if current_price:
+                        break
             else:
-                # print('API error getting current price', e, flush=True)
+                print('API error getting current price', e, flush=True)
                 pass
             return self.last_current_price(symbol)
 
@@ -132,6 +137,7 @@ class BitmexOrder:
         settings = pickle.load(open(self._settings_path, 'rb'))
         self.props[symbol]['stoploss_id'] = settings.symbols[symbol]['last_order_stoploss_id']
         self.props[symbol]['stop_id'] = settings.symbols[symbol]['last_order_stop_id']
+        self.props[symbol]['SL'] = settings.symbols[symbol]['last_order_SL']
         if self.props[symbol]['stoploss_id']:
             try:
                 res = self.client.client.Order.Order_getOrders(
@@ -160,12 +166,13 @@ class BitmexOrder:
     def save_open_id(self, symbol, id, stop_type='normal'):
         settings = pickle.load(open(self._settings_path, 'rb'))
         if stop_type == 'normal':
-            self.props[symbol]['stoploss_id'] = id
+            self.props[symbol]['stop_id'] = id
             settings.symbols[symbol]['last_order_stop_id'] = id
             pickle.dump(settings, file=open(self._settings_path, 'wb'))
         elif stop_type == 'stoploss':
-            self.props[symbol]['stop_id'] = id
+            self.props[symbol]['stoploss_id'] = id
             settings.symbols[symbol]['last_order_stoploss_id'] = id
+            settings.symbols[symbol]['last_order_SL'] = self.props[symbol]['SL']
             pickle.dump(settings, file=open(self._settings_path, 'wb'))
         else:
             print("No Stop Type given.")
@@ -308,13 +315,14 @@ class BitmexOrder:
         except HTTPBadRequest as e:
             print("Error placing market order.", e, flush=True)
 
-    def modifiy_stop(self, symbol, newPrice):
+    def modifiy_stop(self, symbol, newStopLoss):
         try:
             # could be clOrdID, not sure difference
             res = self.client.client.Order.Order_amend(
                 origClOrdID=self.props[symbol]['stoploss_id'], stopPx=self.price_decimals(symbol,
-                                                                                          newPrice)
+                                                                                          newStopLoss)
             ).result()
+            self.props[symbol]['SL'] = newStopLoss
             return res
         except HTTPBadRequest as e:
             if 'Invalid amend' in str(e):
