@@ -11,6 +11,7 @@ def run():
     # entrypoint
     pass
 
+
 class BrokerSettings:
     token = ''
     api_key = ''
@@ -50,7 +51,8 @@ def file_create_input(check_exist=True, symbols=['XBTUSD'], broker='bitmex', str
             pos_size = input(
                 "Choose your Position Size for {} per trade in %: ".format(symbol))
             pos_size = check_pos_size(pos_size)
-            symbol_settings[symbol] = {'position_size': pos_size, 'last_order_stop_id': '', 'last_order_stoploss_id': ''}
+            symbol_settings[symbol] = {
+                'position_size': pos_size, 'last_order_stop_id': '', 'last_order_stoploss_id': '', 'last_order_SL': '', 'last_order_qty': ''}
         return make_pickle_file(setting_name, token, api_key, api_secret, symbol_settings)
 
 
@@ -80,7 +82,7 @@ def check_pos_size(pos_size, max_position_size=10):
 
 
 def check_settings(settings, symbols, broker, strategy):
-    print('check settings')
+    print('--Check Settings--')
     while True:
         qr = input("Start Algo Trader Bot with"
                    "\n\tBroker: " + broker.replace('_', ' ').title() +
@@ -154,6 +156,7 @@ if args.run in ['run', 'Run', 'RUN']:
     else:
         start_settings = file_create_input(
             symbols=symbols, broker=broker, strategy=args.strategy)
+        input("--Settings Saved--\nPress ENTER to strat the bot now!")
 
     setting_file_name = '{}_{}_settings.pickle'.format(broker, args.strategy)
 
