@@ -9,6 +9,7 @@ import os
 import signal
 import sys
 
+
 class Lotus:
     def __init__(self, client, symbols, settings, setting_file_name):
         self.client = client
@@ -66,8 +67,8 @@ class Lotus:
         try:
             return requests.get(self._api_endpoint, params=auth).json()
         except ValueError:
-            print("Can't get signal on endpoint {} with token {}. Please make sure your token is the right one and endpoint is set correct."
-                  " It could also be that you are timed out because you try to access with multiple IP's. In this case wait 40 minutes to be able to access again.".format(
+            print("Can't get signal on endpoint {} with token {}."
+                  "It could be that you are timed out because you try to access with multiple IP's.\nIn this case wait 40 minutes to be able to access again.\(Don't need to restart)".format(
                       self._api_endpoint, self.settings.token))
             return False
 
@@ -94,11 +95,11 @@ class Lotus:
     def manage_open_stop_orders(self, symbol):
         if self.order.props[symbol]['wait_stop']:
             print("Cancel old order {} first.".format(symbol))
-            self.order.stoporder_cancel(symbol)  # cancel old order first
+            self.order.stoporder_cancel(symbol)
             time.sleep(3)
         elif self.order.props[symbol]['open']:
             print("Close old order {} first, because of new signal".format(symbol))
-            self.order.close(symbol, -self.client.open_contracts(symbol))  # cancel old order first
+            self.order.close(symbol, -self.client.open_contracts(symbol))
             time.sleep(3)
 
     def process_signals(self, ns, start=False):
@@ -192,7 +193,6 @@ class Lotus:
 
     def run(self):
         # Main loop
-        print("BOT IS RUNNING... **(ignore the warning above)**", flush=True)
         self.order = BitmexOrder(self.symbols,
                                  self.client, self.settings, self._settings_path)
         while True:
@@ -202,6 +202,7 @@ class Lotus:
                 time.sleep(60)
             else:
                 self.process_signals(signal, start=True)
+                print("BOT IS RUNNING... **(ignore the warning above)**", flush=True)
                 break
         while True:
             time.sleep(10)
@@ -214,14 +215,12 @@ class Lotus:
                 while True:
                     signal = self.get_api_signal()
                     if not signal:
+                        # in case the receiving of signal is not authorized
                         break
                     elif self.is_new_signal(signal):
                         # make sure to get the signal
                         self.process_signals(signal)
                         break
-                    elif not signal:
-                        # in case the receiving of signal is not authorized
-                        break
                     count_s_tries += 1
                     if count_s_tries > 15:
                         print('Signal is offline', flush=True)
